/*------------------------------------------------------------------------------*
 * Architecture & Implementation of DBMS                                        *
 *------------------------------------------------------------------------------*
 * Copyright 2019 Databases and Information Systems Group TU Dortmund          *
 *                                                                              *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS      *
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,  *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL      *
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR         *
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,        *
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR        *
 * OTHER DEALINGS IN THE SOFTWARE.                                              *
 *------------------------------------------------------------------------------*
 */

#pragma once

#include <cstdint>
#include <string>
#include <benchmarks/workload.h>
#include "base/simple_tables.h"

namespace aidbms::benchmarks {

    class JoinWorkload : public Workload<std::vector<aidbms::simple_tables::VALUE_TYPE>>
    {
    public:
        /**
         * @brief JoinWorkload reads, parses the file at the specified path and generates a join
         * workload.
         * @param workload_file_name path to file
         */
        JoinWorkload(const char *workload_file_name, std::string relation_name, std::vector<std::string> column_names);

        operator aidbms::simple_tables::Relation() const {
            return _relation;
        }

    private:
        aidbms::simple_tables::Relation _relation;
    };
}
